@@ -1,7 +1,5 @@
 //! Matrix of an arbitrary type and utilities to rotate, transpose, etc.
 
-extern crate itertools;
-
 use num_traits::Signed;
 use std::ops::{Index, IndexMut, Neg, Range};
 
@@ -41,7 +39,7 @@ impl<C: Clone> Matrix<C> {
     }
 
     /// Return a copy of a sub-matrix.
-    #[cfg_attr(feature = "cargo-clippy", allow(clippy::needless_pass_by_value))]
+    #[allow(clippy::needless_pass_by_value)]
     pub fn slice(&self, rows: Range<usize>, columns: Range<usize>) -> Matrix<C> {
         let height = rows.end - rows.start;
         let width = columns.end - columns.start;
@@ -292,6 +290,24 @@ impl<C> Matrix<C> {
     pub fn rotate_ccw(&mut self, times: usize) {
         self.rotate_cw(4 - (times % 4))
     }
+
+    /// Return an iterator on neighbours of a given matrix cell, with or
+    /// without considering diagonals.
+    pub fn neighbours(
+        &self,
+        index: &(usize, usize),
+        diagonals: bool,
+    ) -> impl Iterator<Item = (usize, usize)> {
+        let &(r, c) = index;
+        let min_dr = if r == 0 { 0 } else { -1 };
+        let max_dr = if r == self.rows - 1 { 0 } else { 1 };
+        let min_dc = if c == 0 { 0 } else { -1 };
+        let max_dc = if c == self.columns - 1 { 0 } else { 1 };
+        (min_dc..=max_dc)
+            .flat_map(move |dc| (min_dr..=max_dr).map(move |dr| (dr, dc)))
+            .filter(move |&(dr, dc)| (diagonals && dr != 0 && dc != 0) || dr.abs() + dc.abs() == 1)
+            .map(move |(dr, dc)| ((r as isize + dr) as usize, (c as isize + dc) as usize))
+    }
 }
 
 impl<'a, C> Index<&'a (usize, usize)> for Matrix<C> {
